function getHeaderHeight(gridApi) {
    // DANGER: using ag-grid internals
    const headerCtrl = gridApi.getDisplayedRowAtIndex?.(0)?.beans?.ctrlsSvc?.get("gridHeaderCtrl");
    if (!headerCtrl) {
        // in some cases there is not displayed row at index 0, e.g.
        //try to get dirty internal height of the grid
        return gridApi.getSizesForCurrentTheme().headerHeight;
    }
    return headerCtrl?.eGui?.clientHeight ?? 0;
}
function getCellElement(gridApi, attributeId, rowIndex) {
    // DANGER: using ag-grid internals
    const rowRenderer = gridApi.getDisplayedRowAtIndex?.(rowIndex)?.beans?.rowRenderer;
    if (!rowRenderer)
        return null;
    const centerCellCtrls = rowRenderer.getAllCellCtrls().filter((r) => r.rowNode.rowIndex === rowIndex);
    const cell = centerCellCtrls?.find((col) => {
        return col.column.colId === attributeId;
    });
    return cell?.eGui ?? null;
}
function addCellClass(gridApi, attributeId, rowIndex, className) {
    const cellElement = getCellElement(gridApi, attributeId, rowIndex);
    if (cellElement !== null) {
        cellElement.classList.add(className);
    }
}
function removeCellClass(gridApi, attributeId, rowIndex, className) {
    const cellElement = getCellElement(gridApi, attributeId, rowIndex);
    if (cellElement !== null) {
        cellElement.classList.remove(className);
    }
}
function getPinnedTopRowElement(gridApi) {
    const pinnedTopRow = gridApi.getPinnedTopRow(0);
    if (!pinnedTopRow) {
        return null;
    }
    // DANGER: using ag-grid internals
    const rootElement = pinnedTopRow.beans?.ctrlsSvc?.getGridBodyCtrl?.()?.eGridBody;
    const rowElement = rootElement?.querySelector(`[row-id=${pinnedTopRow.id}]`);
    return rowElement?.parentElement?.parentElement?.parentElement ?? null;
}
function addPinnedTopRowClass(gridApi, className) {
    const rowElement = getPinnedTopRowElement(gridApi);
    if (rowElement) {
        rowElement.classList.add(className);
    }
}
function removePinnedTopRowClass(gridApi, className) {
    const rowElement = getPinnedTopRowElement(gridApi);
    if (rowElement) {
        rowElement.classList.remove(className);
    }
}
function setPinnedTopRowStyles(gridApi, styles) {
    const rowElement = getPinnedTopRowElement(gridApi);
    if (rowElement) {
        for (const [key, value] of Object.entries(styles)) {
            rowElement.style[key] = value;
        }
    }
}
export default {
    getHeaderHeight,
    // cell element
    getCellElement,
    addCellClass,
    removeCellClass,
    // pinned row element
    getPinnedTopRowElement,
    addPinnedTopRowClass,
    removePinnedTopRowClass,
    setPinnedTopRowStyles,
    // pinned row cell element
};
//# sourceMappingURL=agApiWrapper.js.map