// (C) 2007-2025 GoodData Corporation
import cx from "classnames";
import { isResultTotalHeader } from "@gooddata/sdk-model";
import { ClientFormatterFacade } from "@gooddata/number-formatter";
import { isMixedValuesCol, isScopeCol } from "../structure/tableDescriptorTypes.js";
import { COLUMN_TOTAL, COLUMN_SUBTOTAL } from "../base/constants.js";
function getFormattedNumber(value, format, separators) {
    const parsedNumber = ClientFormatterFacade.convertValue(value);
    return ClientFormatterFacade.formatValue(parsedNumber, format, separators);
}
// TODO: move to cell class; refactor tests
export function getCellClassNames(rowIndex, columnIndex, isDrillable) {
    return cx({
        "gd-cell-drillable": isDrillable,
    }, "gd-cell", `s-cell-${rowIndex}-${columnIndex}`, "s-table-cell");
}
export function getMeasureCellFormattedValue(value, format, separators) {
    const { formattedValue } = getFormattedNumber(value, format, separators);
    return formattedValue === "" ? "–" : formattedValue;
}
export function getMeasureCellStyle(value, format, separators, applyColor) {
    const { formattedValue, colors } = getFormattedNumber(value, format, separators);
    const color = colors.color;
    const backgroundColor = colors.backgroundColor;
    const measureCellDefault = {
        textAlign: "right",
    };
    if (formattedValue === "") {
        return {
            ...measureCellDefault,
            color: "var(--gd-table-nullValueColor, var(--gd-palette-complementary-6, #94a1ad))",
            fontWeight: "bold",
        };
    }
    if (!applyColor) {
        return {
            ...measureCellDefault,
        };
    }
    return {
        ...measureCellDefault,
        ...(color && { color }),
        ...(backgroundColor && { backgroundColor }),
    };
}
export function getColumnTotalOrSubTotalInfo(colDef, col, row, isTransposed, columnHeadersPosition) {
    if (columnHeadersPosition === "left" && isTransposed) {
        if (Object.keys(row.headerItemMap).length > 0) {
            return {
                isColumnTotal: isMixedValuesCol(col) &&
                    isResultTotalHeader(row.headerItemMap[col.id]) &&
                    col.isTotal === true,
                isColumnSubtotal: isMixedValuesCol(col) &&
                    isResultTotalHeader(row.headerItemMap[col.id]) &&
                    col.isSubtotal === true,
            };
        }
        else {
            return {
                isColumnTotal: isMixedValuesCol(col) && col.isTotal === true,
                isColumnSubtotal: isMixedValuesCol(col) && col.isSubtotal === true,
            };
        }
    }
    else if (isTransposed) {
        return {
            isColumnTotal: isScopeCol(col) && col.isTotal === true,
            isColumnSubtotal: isScopeCol(col) && col.isSubtotal === true,
        };
    }
    else {
        return {
            isColumnTotal: colDef.type === COLUMN_TOTAL,
            isColumnSubtotal: colDef.type === COLUMN_SUBTOTAL,
        };
    }
}
//# sourceMappingURL=cellUtils.js.map