// (C) 2007-2025 GoodData Corporation
import React from "react";
import cx from "classnames";
import { AVAILABLE_TOTALS, HEADER_LABEL_CLASS } from "../../base/constants.js";
import AggregationsMenu from "./AggregationsMenu.js";
export const ALIGN_LEFT = "left";
export const ALIGN_RIGHT = "right";
export default class HeaderCell extends React.Component {
    static defaultProps = {
        sortDirection: null,
        textAlign: ALIGN_LEFT,
        menuPosition: ALIGN_LEFT,
        menu: null,
        enableSorting: false,
        onMenuAggregationClick: () => null,
        onSortClick: () => null,
    };
    resetSortDirection = () => {
        this.setState({
            currentSortDirection: this.props.sortDirection,
        });
    };
    state = {
        isMenuOpen: false,
        isMenuButtonVisible: false,
        currentSortDirection: null,
    };
    componentDidMount() {
        this.resetSortDirection();
    }
    componentDidUpdate(prevProps) {
        if (prevProps.isFocused !== this.props.isFocused) {
            if (this.props.isFocused) {
                this.onMouseEnterHeaderCellText();
            }
            else {
                this.onMouseLeaveHeaderCellText();
            }
        }
    }
    UNSAFE_componentWillReceiveProps(nextProps) {
        if (nextProps.sortDirection !== this.props.sortDirection) {
            this.setState({
                currentSortDirection: this.props.sortDirection,
            });
        }
    }
    render() {
        const { menuPosition, className } = this.props;
        return (React.createElement("div", { className: cx("gd-pivot-table-header", {
                "gd-pivot-table-header--open": this.state.isMenuButtonVisible,
            }, className), onMouseEnter: this.onMouseEnterHeaderCell, onMouseLeave: this.onMouseLeaveHeaderCell },
            menuPosition === "left" && this.renderMenu(),
            this.renderText(),
            menuPosition === "right" && this.renderMenu()));
    }
    renderMenu() {
        const { intl, colId, menu, getTableDescriptor, getExecutionDefinition, getColumnTotals, getRowTotals, } = this.props;
        const { isMenuOpen, isMenuButtonVisible } = this.state;
        if (!menu?.aggregations) {
            return null;
        }
        return (React.createElement(AggregationsMenu, { intl: intl, colId: colId, isMenuOpened: isMenuOpen, isMenuButtonVisible: isMenuButtonVisible, showSubmenu: menu.aggregations ?? false, showColumnsSubMenu: menu.aggregationsSubMenuForRows ?? false, availableTotalTypes: menu.aggregationTypes ?? AVAILABLE_TOTALS, getTableDescriptor: getTableDescriptor, getExecutionDefinition: getExecutionDefinition, getColumnTotals: getColumnTotals, getRowTotals: getRowTotals, onMenuOpenedChange: this.handleMenuOpenedChange, onAggregationSelect: this.menuItemClick }));
    }
    renderText() {
        const { displayText, textAlign, enableSorting } = this.props;
        const classes = cx(HEADER_LABEL_CLASS, "gd-pivot-table-header-label", {
            "gd-pivot-table-header-label--right": textAlign === "right",
            "gd-pivot-table-header-label--center": textAlign === "center",
            "gd-pivot-table-header-label--clickable": enableSorting,
        });
        return (React.createElement("div", { className: classes, onClick: this.onTextClick, onMouseEnter: this.onMouseEnterHeaderCellText, onMouseLeave: this.onMouseLeaveHeaderCellText },
            React.createElement("span", null, displayText ? displayText : ""),
            this.renderSorting()));
    }
    renderSorting() {
        const { enableSorting } = this.props;
        const { currentSortDirection } = this.state;
        const sortClasses = cx("s-sort-direction-arrow", `s-sorted-${currentSortDirection}`, {
            "gd-pivot-table-header-arrow-up": currentSortDirection === "asc",
            "gd-pivot-table-header-arrow-down": currentSortDirection === "desc",
        });
        return (currentSortDirection &&
            enableSorting && (React.createElement("span", { className: "gd-pivot-table-header-next-sort" },
            React.createElement("span", { className: sortClasses }))));
    }
    onMouseEnterHeaderCell = () => {
        this.showMenuButton();
    };
    onMouseLeaveHeaderCell = () => {
        this.hideMenuButton();
    };
    onMouseEnterHeaderCellText = () => {
        if (this.props.enableSorting) {
            const { sortDirection } = this.props;
            let newSortDirection = null;
            if (sortDirection === null) {
                newSortDirection = this.props.defaultSortDirection ?? null;
            }
            else if (sortDirection === "asc") {
                newSortDirection = "desc";
            }
            else if (sortDirection === "desc") {
                newSortDirection = "asc";
            }
            else {
                newSortDirection = null;
            }
            this.setState({
                currentSortDirection: newSortDirection,
            });
        }
    };
    onMouseLeaveHeaderCellText = () => {
        this.resetSortDirection();
    };
    onTextClick = () => {
        const { onSortClick, enableSorting } = this.props;
        if (!enableSorting) {
            return;
        }
        onSortClick();
    };
    showMenuButton = () => {
        if (this.state.isMenuOpen) {
            return;
        }
        this.setState({
            isMenuButtonVisible: true,
        });
    };
    hideMenuButton = () => {
        if (this.state.isMenuOpen) {
            return;
        }
        this.setState({
            isMenuButtonVisible: false,
        });
    };
    hideAndCloseMenu = () => {
        this.setState({
            isMenuButtonVisible: false,
            isMenuOpen: false,
        });
    };
    menuItemClick = (menuAggregationClickConfig) => {
        this.hideAndCloseMenu();
        if (this.props.onMenuAggregationClick) {
            this.props.onMenuAggregationClick(menuAggregationClickConfig);
        }
    };
    handleMenuOpenedChange = ({ opened, source }) => {
        this.setState({
            isMenuOpen: opened,
        });
        // When source is 'TOGGLER_BUTTON_CLICK' we do not want to hide menu
        // button visibility. Because user is hovering over this button
        // so we do not want to hide it.
        if (source === "OUTSIDE_CLICK" || source === "SCROLL") {
            this.setState({
                isMenuButtonVisible: false,
            });
        }
    };
}
//# sourceMappingURL=HeaderCell.js.map